@@ -394,7 +394,7 @@ function(object, ..., Distribution = NULL,
 
   # Plot. X-axis starts at 0.01 to avoid the 0 X-label.
   thePlot <- ggplot2::ggplot() +
-    ggplot2::geom_point(data=df, mapping=ggplot2::aes_(x=~Rank, y=~Ns), 
+    ggplot2::geom_point(data=df, mapping=ggplot2::aes(x=.data$Rank, y=.data$Ns), 
                         shape=pch, color=col, size=cex) +
     ggplot2::scale_x_continuous(limits=c(0.01, S), expand=c(0, 0)) +
     ggplot2::labs(title=main, x=xlab, y=ylab)
@@ -425,7 +425,8 @@ function(object, ..., Distribution = NULL,
     if (OK) {
       # Add the adjusted curve to the plot
       thePlot <- thePlot + 
-        ggplot2::geom_line(data=with(FittedRAC, data.frame(Rank, Abundance)), mapping=ggplot2::aes_(x=~Rank, y=~Abundance, col="red")) + 
+        ggplot2::geom_line(data=with(FittedRAC, data.frame(Rank, Abundance)), 
+                           mapping=ggplot2::aes(x=.data$Rank, y=.data$Abundance, col="red")) + 
         ggplot2::theme(legend.position="none")
       # Add fitted parameters to the attributes of the plot
       if (Distribution == "lnorm") {
@@ -493,7 +494,8 @@ function (Ns, CheckArguments = TRUE)
   Rank <- seq_len(S)
   reg <- stats::lm(lNs~Rank)
   
-  return(list(Rank=Rank, Abundance=exp(reg$coefficients[1]+reg$coefficients[2]*Rank), prob=as.numeric(-reg$coefficients[2])))
+  return(list(Rank=Rank, Abundance=exp(reg$coefficients[1]+reg$coefficients[2]*Rank), 
+              prob=as.numeric(-reg$coefficients[2])))
 }
 
 
